changeset 752:21eedd1b9fa9 draft

Updated several tests.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Fri, 14 Aug 2015 12:04:03 +0200
parents a55ded659895
children 03a29500ef5b
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 71 insertions(+), 66 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Thu Aug 13 10:23:30 2015 +0200
+++ b/ChangeLog	Fri Aug 14 12:04:03 2015 +0200
@@ -1,3 +1,8 @@
+2015-08-14  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
 2015-08-13  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Aug 13 10:23:30 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Fri Aug 14 12:04:03 2015 +0200
@@ -10150,13 +10150,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10165,13 +10165,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -10180,13 +10180,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -10195,13 +10195,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -10210,13 +10210,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -10225,13 +10225,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -10240,13 +10240,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10255,13 +10255,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10270,13 +10270,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10285,9 +10285,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.red);
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB_Pre(image, graphics2d, Color.red);
     }
 
     /**